import pytest

from obfsc8.src.obfsc8.get_columns_to_be_obfuscated \
    import get_columns_to_be_obfuscated
from test_data.test_json import test_json
from test_data.test_json_targeting_student_id \
    import test_json_targeting_student_id


def test_that_list_returned():
    restricted_fields = []
    result = get_columns_to_be_obfuscated(test_json, restricted_fields)

    assert isinstance(result, list)


def test_that_list_contains_correct_column_names():
    restricted_fields = []
    result = get_columns_to_be_obfuscated(test_json, restricted_fields)

    assert result == ["name", "email_address"]


@pytest.mark.parametrize(
    "restricted_fields, expected", [
        (["student_id"], [
            "name", "email_address"]), ([], [
                "student_id", "name", "email_address"])])
def test_that_restricted_fields_correctly_removed_from_column_names(
        restricted_fields, expected):
    result = (get_columns_to_be_obfuscated
              (test_json_targeting_student_id, restricted_fields))

    assert result == expected



from moto import mock_aws
import pandas as pd
import boto3
import io

from obfsc8.src.obfsc8.obfuscate \
    import obfuscate
from test_data.test_dataframe import test_dataframe


@mock_aws
def test_that_csv_file_results_in_csv_bytes_object():
    s3 = boto3.client('s3', region_name="eu-west-2")

    s3.create_bucket(Bucket="test_bucket",
                     CreateBucketConfiguration={
                            'LocationConstraint': "eu-west-2"
                     }
                     )

    test_csv = test_dataframe.write_csv()
    s3.put_object(Bucket="test_bucket", Key="test_csv.csv", Body=test_csv)

    test_csv_json = """{
    "file_to_obfuscate": "s3://test_bucket/test_csv.csv",
    "pii_fields": ["name", "email_address"]
    }"""

    buffer = obfuscate(test_csv_json)
    df = pd.read_csv(buffer)
    assert isinstance(df, pd.DataFrame)


@mock_aws
def test_that_parquet_file_results_in_parquet_bytes_object():
    s3 = boto3.client('s3', region_name="eu-west-2")
    s3.create_bucket(Bucket="test_bucket",
                     CreateBucketConfiguration={
                            'LocationConstraint': "eu-west-2"
                     }
                     )

    test_parquet = io.BytesIO()
    test_dataframe.write_parquet(test_parquet)
    test_parquet.seek(0)
    s3.put_object(
        Bucket="test_bucket",
        Key="test_parquet.parquet",
        Body=test_parquet)

    test_parquet_json = """{
    "file_to_obfuscate": "s3://test_bucket/test_parquet.parquet",
    "pii_fields": ["name", "email_address"]
    }"""
    buffer = obfuscate(test_parquet_json)
    df = pd.read_parquet(buffer)
    assert isinstance(df, pd.DataFrame)


@mock_aws
def test_that_json_file_results_in_json_bytes_object():
    s3 = boto3.client('s3', region_name="eu-west-2")
    s3.create_bucket(Bucket="test_bucket",
                     CreateBucketConfiguration={
                            'LocationConstraint': "eu-west-2"
                     }
                     )

    test_json_file = test_dataframe.write_json(row_oriented=True)
    s3.put_object(
        Bucket="test_bucket",
        Key="test_json.json",
        Body=test_json_file)

    test_json_json = """{
    "file_to_obfuscate": "s3://test_bucket/test_json.json",
    "pii_fields": ["name", "email_address"]
    }"""
    buffer = obfuscate(test_json_json)
    df = pd.read_json(buffer)
    assert isinstance(df, pd.DataFrame)



import pytest

from obfsc8.src.obfsc8.get_filetype import get_filetype


def test_that_string_returned():
    filename = "new_data/file1.csv"
    result = get_filetype(filename)

    assert isinstance(result, str)


@pytest.mark.parametrize("filename, expected",
                         [("new_data/file1.csv",
                           "csv"),
                          ("new_data/file1.parquet",
                           "parquet"),
                             ("new_data/file1.json",
                              "json")])
def test_correct_filetype_returned_for_all_expected_filetypes(
        filename,
        expected):
    result = get_filetype(filename)

    assert result == expected


def test_that_type_error_raised_if_input_filename_not_a_string():
    with pytest.raises(TypeError, match="must be a string"):
        get_filetype(674)


def test_that_value_error_raised_if_period_not_present_in_filename():
    with pytest.raises(ValueError, match="must contain a period"):
        get_filetype("new_data/file1")


def test_that_value_error_raised_if_filetype_not_CSV_Parquet_or_JSON():
    with (pytest.raises
          (ValueError, match="Filetype must be CSV, Parquet or JSON")):
        get_filetype("new_data/file1.jpg")



import polars.testing as pt
import polars as pl

from test_data.test_dataframe import test_dataframe


def test_that_s3_csv_written_and_retrieved_without_data_change(csv_from_s3):
    csv_file_from_s3_as_df = pl.read_csv(csv_from_s3)
    pt.assert_frame_equal(test_dataframe, csv_file_from_s3_as_df)


def test_that_s3_parquet_written_and_retrieved_without_data_change(
        parquet_from_s3):
    parquet_file_from_s3_as_df = pl.read_parquet(parquet_from_s3)
    pt.assert_frame_equal(test_dataframe, parquet_file_from_s3_as_df)


def test_that_s3_json_written_and_retrieved_without_data_change(json_from_s3):
    json_file_from_s3_as_df = pl.read_json(json_from_s3.read())
    pt.assert_frame_equal(test_dataframe, json_file_from_s3_as_df)
